<?php
/*
Plugin Name: MP6
Plugin URI: http://wordpress.org/extend/plugins/mp6/
Description: This is a plugin to break the wp-admin UI, and is not recommended for non-savvy users.
Version: 1.8
Author:
Author URI: http://wordpress.org
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/


// load the responsive component of MP6
if ( ( ! defined( 'IFRAME_REQUEST' ) || IFRAME_REQUEST !== true ) && ! isset( $_GET[ 'iframe' ] ) )
	require_once( plugin_dir_path(__FILE__) . 'components/responsive/moby6.php' );

// load the sticky admin menu component
require_once( plugin_dir_path(__FILE__) . 'components/sticky-menu/sticky-menu.php' );

// register Open Sans stylesheet
add_action( 'init', 'mp6_register_open_sans' );
function mp6_register_open_sans() {
	wp_register_style(
		'open-sans',
		'//fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,300,400,600&subset=latin-ext,latin',
		false,
		'20130605'
	);
}

// register Dashicons stylesheet
add_action( 'init', 'mp6_register_dashicons' );
function mp6_register_dashicons() {
	wp_register_style(
		'dashicons',
		plugins_url( 'css/dashicons.css', __FILE__ ),
		false,
		filemtime( plugin_dir_path( __FILE__ ) . 'css/dashicons.css' )
	);
}

// register MP6 admin color scheme
add_action( 'admin_init', 'mp6_register_admin_color_scheme' );
function mp6_register_admin_color_scheme() {

	global $wp_styles, $_wp_admin_css_colors;

	// remove classic and fresh color schemes, to prevent confusion
	unset( $_wp_admin_css_colors[ 'classic' ] );
	unset( $_wp_admin_css_colors[ 'fresh' ] );

	wp_admin_css_color(
		'mp6',
		_x( 'MP6', 'admin color scheme' ),
		plugins_url( 'css/colors-mp6.css', __FILE__ ),
		array( '#333', '#444', '#0074a2', '#2ea2cc' )
	);

	// set colors-mp6.css's modification time
	$wp_styles->registered[ 'colors' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/colors-mp6.css' );
	$wp_styles->registered[ 'colors' ]->deps[] = 'open-sans';
	$wp_styles->registered[ 'colors' ]->deps[] = 'dashicons';
}

// load MP6 css on login screen
add_action( 'login_init', 'mp6_replace_wp_default_styles' );
add_action( 'login_init', 'mp6_fix_login_color_scheme' );
function mp6_fix_login_color_scheme() {
	global $wp_styles;
	$wp_styles->registered[ 'colors-fresh' ]->src = plugins_url( 'css/colors-mp6.css', __FILE__ );
	$wp_styles->registered[ 'colors-fresh' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/colors-mp6.css' );
	$wp_styles->registered[ 'colors-fresh' ]->deps[] = 'open-sans';
	$wp_styles->registered[ 'colors-fresh' ]->deps[] = 'dashicons';
}

// replace default admin-bar.css with MP6's
add_action( 'init', 'mp6_replace_admin_bar_style' );
function mp6_replace_admin_bar_style() {
	global $wp_styles;
	$wp_styles->registered[ 'admin-bar' ]->src = plugins_url( 'css/admin-bar.css', __FILE__ );
	$wp_styles->registered[ 'admin-bar' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/admin-bar.css' );
	$wp_styles->registered[ 'admin-bar' ]->deps[] = 'open-sans';
	$wp_styles->registered[ 'admin-bar' ]->deps[] = 'dashicons';
	$wp_styles->registered[ 'admin-bar' ]->extra[ 'suffix' ] = '';
}

// replace some default css files with ours
add_action( 'admin_init', 'mp6_replace_wp_default_styles' );
function mp6_replace_wp_default_styles() {
	global $wp_styles;
	$wp_styles->registered[ 'buttons' ]->src = plugins_url( 'css/buttons.css', __FILE__ );
	$wp_styles->registered[ 'buttons' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/buttons.css' );
	$wp_styles->registered[ 'editor-buttons' ]->src = plugins_url( 'css/editor.css', __FILE__ );
	$wp_styles->registered[ 'editor-buttons' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/editor.css' );
	$wp_styles->registered[ 'media' ]->src = plugins_url( 'css/media.css', __FILE__ );
	$wp_styles->registered[ 'media' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/media.css' );
	$wp_styles->registered[ 'media-views' ]->src = plugins_url( 'css/media-views.css', __FILE__ );
	$wp_styles->registered[ 'media-views' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/media-views.css' );
	$wp_styles->registered[ 'media-views' ]->extra[ 'suffix' ] = '';
	$wp_styles->registered[ 'wp-admin' ]->src = plugins_url( 'css/wp-admin.css', __FILE__ );
	$wp_styles->registered[ 'wp-admin' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/wp-admin.css' );
	$wp_styles->registered[ 'wp-admin' ]->deps[] = 'open-sans';
	$wp_styles->registered[ 'wp-admin' ]->deps[] = 'dashicons';
	$wp_styles->registered[ 'wp-admin' ]->extra[ 'suffix' ] = '';
	$wp_styles->registered[ 'wp-pointer' ]->src = plugins_url( 'css/wp-pointer.css', __FILE__ );
	$wp_styles->registered[ 'wp-pointer' ]->ver = filemtime( plugin_dir_path( __FILE__ ) . 'css/wp-pointer.css' );
}

// force the MP6 color-scheme setting on to use the new CSS
add_filter( 'get_user_option_admin_color', 'mp6_force_admin_color' );
function mp6_force_admin_color( $color_scheme ) {
	return 'mp6';
}

// Add an MP6 body class to the front-end
add_filter( 'body_class', 'mp6_add_body_class_frontend' );
function mp6_add_body_class_frontend( $classes ) {
	$classes[] = 'mp6';
	return $classes;
}

// Add an MP6 body class to the back-end
add_filter( 'admin_body_class', 'mp6_add_body_class_backend' );
function mp6_add_body_class_backend( $classes ) {
	if ( is_multisite() )
		$classes .= ' multisite';
	return $classes . ' mp6 ';
}

// override WP's default toolbar top margin
add_action( 'wp_head', 'mp6_override_toolbar_margin', 11 );
function mp6_override_toolbar_margin() {
	if ( is_admin_bar_showing() ) : ?>
<style type="text/css" media="screen">
	html { margin-top: 32px !important; }
	* html body { margin-top: 32px !important; }

	@media screen and ( max-width: 782px ) {
		html { margin-top: 46px !important; }
		* html body { margin-top: 46px !important; }
	}
</style>
<?php endif;
}